==> hyades.source_3.2.0_20041101_1032.zip: org/eclipse/hyades/trace/views/adapter/internal/MemoryStatisticViewer.java <==
/**********************************************************************
 * Copyright (c) 2004 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.trace.views.adapter.internal;

import java.util.Vector;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.hyades.trace.ui.TraceViewerPage;
import org.eclipse.hyades.trace.views.internal.MemoryStatisticView;
import org.eclipse.hyades.trace.views.internal.TracePluginImages;
import org.eclipse.hyades.trace.views.internal.TraceUIPlugin;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.action.Separator;

public class MemoryStatisticViewer extends MultiLevelStatisticViewer {

	protected Action _percentMode;
	protected Action _deltaColumns;	
	
	protected Action _instanceLevel;		
	
	protected static final String _title =
		TraceUIPlugin.getString("STR_MEMORY_ST_TITLE");

	public MemoryStatisticViewer() {
		super();
	}

	/**
	 * create a coverage page
	 */
	public TraceViewerPage createPage(EObject mofObject) {
		return new MemoryStatisticPage(mofObject, this);
	}

	/**
	 * return the view title
	 */
	public String getViewTitle() {
		return _title;
	}
	
	protected void getLevelActions(Vector actions)
	{
		super.getLevelActions(actions);
		
		String strInstanceLevel = TraceUIPlugin.getString("STR_ST_INSTANCE_LEVEL");

		_instanceLevel = new Action(strInstanceLevel) {
			public void run() {
				MultiLevelStatisticPage page = (MultiLevelStatisticPage) getCurrentPage();

				if (page == null)
					return;

				setCheckedLevels(page, MemoryStatisticView.INSTANCE_LEVEL);

			}
			public int getStyle() {
				return IAction.AS_CHECK_BOX;
			}
		};
		_instanceLevel.setText(strInstanceLevel);
		TracePluginImages.setImageDescriptors(
				_instanceLevel,
			TracePluginImages.T_LCL,
			TracePluginImages.IMG_OBJ);
		_instanceLevel.setDescription(strInstanceLevel);
		_instanceLevel.setToolTipText(strInstanceLevel);
		_instanceLevel.setEnabled(true);

		actions.addElement(new Separator());
		actions.addElement(_instanceLevel);		
	}
	
	public void getActions(Vector actions)
	{
	 	String strShowPercent = TraceUIPlugin.getString("SHOW_PERCENT");  	  										
		_percentMode = new Action(strShowPercent)
		{
			public void run()
			{
				MemoryStatisticPage page = (MemoryStatisticPage)getCurrentPage();

				if(page == null)
				  return;
				page.getView().getShowPercentAction().run();      
			}
			public int getStyle() { return IAction.AS_CHECK_BOX; }


		};

		_percentMode.setText(strShowPercent);
		TracePluginImages.setImageDescriptors(_percentMode,TracePluginImages.T_LCL,TracePluginImages.IMG_PERCENT);			
		_percentMode.setDescription(strShowPercent);   
		_percentMode.setToolTipText(strShowPercent);
		_percentMode.setEnabled(true);

		String strShowDelta = TraceUIPlugin.getString("STR_ST_SHOW_DELTA_COLUMNS");	
		_deltaColumns = new Action(strShowDelta)
		{
			public void run()
			{
				MemoryStatisticPage page = (MemoryStatisticPage)getCurrentPage();

				if(page == null)
				  return;
				page.getView().getDeltaColumnsAction().run();      
			}
			
			public int getStyle() { return IAction.AS_CHECK_BOX; }
		};

		_deltaColumns.setText(strShowDelta);
		TracePluginImages.setImageDescriptors(_deltaColumns,TracePluginImages.T_LCL,TracePluginImages.IMG_DELTACOLUMNS);
		_deltaColumns.setDescription(strShowDelta);   
		_deltaColumns.setToolTipText(strShowDelta);
		_deltaColumns.setEnabled(true);
		
		int actionSize = actions.size();
		
		super.getActions(actions);
		
		if ((actionSize+1)< actions.size())
		{
			actions.insertElementAt(_percentMode, actionSize+2);
			actions.insertElementAt(_deltaColumns, actionSize+3);
		}
		else
		{
			actions.addElement(new Separator());
			actions.addElement(_percentMode);
			actions.addElement(_deltaColumns);
		}	
	}
	
	public Action percentMode() {
		return _percentMode;
	}

	public Action deltaColumns() {
		return _deltaColumns;
	}		
	
	public Action getInstanceLevel() {
		return _instanceLevel;
	}		
	
	protected void setActionsNull()
	{
		super.setActionsNull();
		_instanceLevel = null;
	}		
}

==> hyades.source_3.3.0_20050623_2150.zip: org/eclipse/hyades/trace/views/adapter/internal/MemoryStatisticViewer.java <==
/**********************************************************************
 * Copyright (c) 2005 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * $Id: MemoryStatisticViewer.java,v 1.8 2005/03/07 16:58:50 ewchan Exp $
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.trace.views.adapter.internal;

import java.util.Vector;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.hyades.trace.ui.TraceViewerPage;
import org.eclipse.hyades.trace.views.internal.MemoryStatisticView;
import org.eclipse.hyades.trace.views.internal.TracePluginImages;
import org.eclipse.hyades.trace.views.internal.TraceUIPlugin;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.action.Separator;

public class MemoryStatisticViewer extends MultiLevelStatisticViewer {

	protected Action _percentMode;
	protected Action _deltaColumns;	
	
	protected Action _instanceLevel;		
	
	protected static final String _title =
		TraceUIPlugin.getString("STR_MEMORY_ST_TITLE");

	public MemoryStatisticViewer() {
		super();
	}

	/**
	 * create a coverage page
	 */
	public TraceViewerPage createPage(EObject mofObject) {
		return new MemoryStatisticPage(mofObject, this);
	}

	/**
	 * return the view title
	 */
	public String getViewTitle() {
		return _title;
	}
	
	protected void getLevelActions(Vector actions)
	{
		super.getLevelActions(actions);
		
		String strInstanceLevel = TraceUIPlugin.getString("STR_ST_INSTANCE_LEVEL");

		_instanceLevel = new Action(strInstanceLevel) {
			public void run() {
				MultiLevelStatisticPage page = (MultiLevelStatisticPage) getCurrentPage();

				if(page == null)
				{
				  revertChecked(_instanceLevel);
				  return;
				}

				setCheckedLevels(page, MemoryStatisticView.INSTANCE_LEVEL);

			}
			public int getStyle() {
				return IAction.AS_CHECK_BOX;
			}
		};
		_instanceLevel.setText(strInstanceLevel);
		TracePluginImages.setImageDescriptors(
				_instanceLevel,
			TracePluginImages.T_LCL,
			TracePluginImages.IMG_OBJ);
		_instanceLevel.setDescription(strInstanceLevel);
		_instanceLevel.setToolTipText(strInstanceLevel);
		_instanceLevel.setEnabled(true);

		actions.addElement(new Separator());
		actions.addElement(_instanceLevel);		
	}
	
	public void getActions(Vector actions)
	{
	 	String strShowPercent = TraceUIPlugin.getString("SHOW_PERCENT");  	  										
		_percentMode = new Action(strShowPercent)
		{
			public void run()
			{
				MemoryStatisticPage page = (MemoryStatisticPage)getCurrentPage();

				if(page == null)
				{
				  revertChecked(_percentMode);
				  return;
				}
				
				page.getView().getShowPercentAction().run();      
			}
			public int getStyle() { return IAction.AS_CHECK_BOX; }


		};

		_percentMode.setText(strShowPercent);
		TracePluginImages.setImageDescriptors(_percentMode,TracePluginImages.T_LCL,TracePluginImages.IMG_PERCENT);			
		_percentMode.setDescription(strShowPercent);   
		_percentMode.setToolTipText(strShowPercent);
		_percentMode.setEnabled(true);

		String strShowDelta = TraceUIPlugin.getString("STR_ST_SHOW_DELTA_COLUMNS");	
		_deltaColumns = new Action(strShowDelta)
		{
			public void run()
			{
				MemoryStatisticPage page = (MemoryStatisticPage)getCurrentPage();

				if(page == null)
				{
				  revertChecked(_deltaColumns);
				  return;
				}
				
				page.getView().getDeltaColumnsAction().run();      
			}
			
			public int getStyle() { return IAction.AS_CHECK_BOX; }
		};

		_deltaColumns.setText(strShowDelta);
		TracePluginImages.setImageDescriptors(_deltaColumns,TracePluginImages.T_LCL,TracePluginImages.IMG_DELTACOLUMNS);
		_deltaColumns.setDescription(strShowDelta);   
		_deltaColumns.setToolTipText(strShowDelta);
		_deltaColumns.setEnabled(true);
		
		int actionSize = actions.size();
		
		super.getActions(actions);
		
		if ((actionSize+1)< actions.size())
		{
			actions.insertElementAt(_percentMode, actionSize+2);
			actions.insertElementAt(_deltaColumns, actionSize+3);
		}
		else
		{
			actions.addElement(new Separator());
			actions.addElement(_percentMode);
			actions.addElement(_deltaColumns);
		}	
	}
	
	public Action percentMode() {
		return _percentMode;
	}

	public Action deltaColumns() {
		return _deltaColumns;
	}		
	
	public Action getInstanceLevel() {
		return _instanceLevel;
	}		
	
	protected void setActionsNull()
	{
		super.setActionsNull();
		_instanceLevel = null;
	}
//
//	public String[] getTypeDescriptions() {
//		String[] typeDescriptions = new String[1];
//		typeDescriptions[0] = "org.eclipse.hyades.profilingType.memoryHeap";
//		return typeDescriptions;
//	}
}
